Changes
=======

1.5 (2025-11-03)
----------------

- Pin upper versions of dependencies.
  [lenadax]


1.4 (2018-07-16)
----------------

- Python 3 compatibility.
  [rnix]

- Convert doctests to unittests.
  [rnix]


1.3 (2017-03-28)
----------------

- Catch and log exception if select2 cannot be initialized.
  [rnix, 2017-03-28]


1.2 (2017-03-01)
----------------

- Use ``yafowil.utils.entry_point`` decorator.
  [rnix, 2016-06-28]


1.1 (2015-01-23)
----------------

- ``select2`` provides key/term vocabularies for preselected items.
  [rnix, 2014-07-10]

- Remove ``select2input`` blueprint, use ``inputtag`` property of ``select2``
  blueprint instead.
  [rnix, 2014-06-19]

- Provide all available constructor options in blueprint.
  [rnix, 2014-06-19]

- Update select widget to 3.5.0.
  [rnix, 2014-06-19]

1.0
---

- Make it work.
  [thet]
